Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(53)

Unified Diff: sdk/lib/_internal/compiler/implementation/compiler.dart

Issue 133273011: Revert "Rename internal library dart:_collection-dev to dart:_internal." (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: reapply after revert. Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/compiler/implementation/compiler.dart
diff --git a/sdk/lib/_internal/compiler/implementation/compiler.dart b/sdk/lib/_internal/compiler/implementation/compiler.dart
index a49913157ca8a30f9e108da2cbb0f20efea8377a..417ed7b356af112718d1b995bc4135954e1496b7 100644
--- a/sdk/lib/_internal/compiler/implementation/compiler.dart
+++ b/sdk/lib/_internal/compiler/implementation/compiler.dart
@@ -452,7 +452,7 @@ abstract class Compiler implements DiagnosticListener {
// Initialized after mirrorSystemClass has been resolved.
FunctionElement mirrorSystemGetNameFunction;
// Initialized when dart:_collection-dev is loaded.
ClassElement symbolImplementationClass;
// Initialized when symbolImplementationClass has been resolved.
@@ -809,7 +809,7 @@ abstract class Compiler implements DiagnosticListener {
typedDataLibrary = library;
typedDataClass =
findRequiredElement(library, 'TypedData');
- } else if (uri == new Uri(scheme: 'dart', path: '_collection-dev')) {
+ } else if (uri == new Uri(scheme: 'dart', path: '_internal')) {
symbolImplementationClass =
findRequiredElement(library, 'Symbol');
} else if (uri == new Uri(scheme: 'dart', path: 'async')) {
@@ -452,7 +452,7 @@ abstract class Compiler implements DiagnosticListener {
// Initialized after mirrorSystemClass has been resolved.
FunctionElement mirrorSystemGetNameFunction;
- // Initialized when dart:_collection-dev is loaded.
+ // Initialized when dart:_internal is loaded.
ClassElement symbolImplementationClass;
// Initialized when symbolImplementationClass has been resolved.
« no previous file with comments | « sdk/lib/_collection_dev/symbol.dart ('k') | sdk/lib/_internal/compiler/implementation/js_backend/backend.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698